function love.load()
	currentgame = 2
	
	love.graphics.setBackgroundColor(255, 255, 255)
	
	--graphics
	editorwindow = love.graphics.newImage("graphics/editor.png")
	
	gamewindow = love.graphics.newImage("graphics/gamewindow.png")
	closehighlight = love.graphics.newImage("graphics/closehighlight.png")
	close = love.graphics.newImage("graphics/close.png")
	cursor = love.graphics.newImage("graphics/cursor.png")
	
	editorfont = love.graphics.newFont("cour.ttf", 15)
	love.graphics.setFont(editorfont)
	
	closeduration = 0.2
	closetimer = closeduration
	opentimer = closeduration
	
	cursorblinkdelay = 0.35
	cursorblinktimer = 0
	cursorblink = true
	
	charmultiplier = 10
	
	running = false
	
	nextgame()
end

function love.update(dt)
	if running then
		update(dt)
	else
		if closetimer ~= closeduration then
			closetimer = closetimer + dt
			if closetimer > closeduration then
				closetimer = closeduration
				cursorblinktimer = 0
				cursorblink = true
				--start next level of game
			end
		end
		
		if opentimer ~= closeduration then
			opentimer = opentimer + dt
			if opentimer > closeduration then
				opentimer = closeduration
				startgame()
			end
		end
		
		cursorblinktimer = cursorblinktimer + dt
		while cursorblinktimer > cursorblinkdelay do
			cursorblinktimer = cursorblinktimer - cursorblinkdelay
			cursorblink = not cursorblink
		end
	end
	
	--print(typedsymbols, codelength, done)
end

function love.draw()
	love.graphics.draw(editorwindow, 0, 0)
	
	love.graphics.setColor(0, 0, 0)
	
	local charsprinted = 0
	
	local s1 = codestring:split("\n")
	for i = 1, #s1 do
		--linenumber
		love.graphics.setColor(128, 128, 128)
		love.graphics.printf(i, 45, 33+(i-1)*17, 0, "right")
		love.graphics.setColor(0, 0, 0)
		
		local tabs = 0
	
		local s2 = s1[i]:split("\t")
		
		if i ~= #s1 then
			cutoff = -2
		else
			cutoff = -1
		end
		
		local text = string.sub(s1[i], #s2, cutoff)
		for j = 1, #s2-1 do
			if j + charsprinted > typedsymbols then
				break
			end
			text = "    " .. text
			tabs = tabs + 1
		end
		
		if string.len(text) - tabs*3 >= typedsymbols-charsprinted then
			--highlight line
			love.graphics.setColor(232, 232, 255)
			love.graphics.rectangle("fill", 50, 51+(i-1)*17, 700, 17)
			love.graphics.setColor(0, 0, 0)
			
			--cursor
			if cursorblink then
				local x = editorfont:getWidth( string.sub(text, 1, typedsymbols - charsprinted + tabs*3) )
				
				love.graphics.setColor(255, 255, 255)
				love.graphics.draw(cursor, x+49, 51+(i-1)*17)
				love.graphics.setColor(0, 0, 0)
			end
			
			--text
			love.graphics.print(string.sub(text, 1, typedsymbols - charsprinted + tabs*3), 50, 50+(i-1)*17)

			--check if end of the last line
			if i == #s1 and string.len(text) - tabs*3 >= typedsymbols-charsprinted then
				done = true
				typedsymbols = string.len(text) - tabs*3 + charsprinted
			end		
			
			break			
		else
			--text
			love.graphics.print(text, 50, 50+(i-1)*17)
		end
		
		charsprinted = charsprinted + string.len(s1[i])
	end
	love.graphics.setColor(255, 255, 255)
	
	if running then
		love.graphics.draw(gamewindow, 59, 18)
		if onclosebutton() then
			love.graphics.draw(closehighlight, 660, 18)
		else
			love.graphics.draw(close, 660, 18)
		end
		
		love.graphics.setColor(0, 0, 0)
		love.graphics.rectangle("fill", 80, 60, 640, 480)
		love.graphics.setColor(255, 255, 255)
		
		love.graphics.setScissor(80, 60, 640, 480)
		
		love.graphics.translate(80, 60)
		if draw then
			draw()
		end
		love.graphics.setScissor()
		
	elseif closetimer ~= closeduration then --CLOSING ANIMATION
		local alpha = 255 - (closetimer/closeduration * 255)
		local scale = 0.08 - closetimer/closeduration * 0.08 + 0.92
		
		love.graphics.setColor(255, 255, 255, alpha)
		love.graphics.draw(gamewindow, 400, 300, 0, scale, scale, 341, 282)
		love.graphics.draw(closehighlight, 400, 300, 0, scale, scale, -260, 282)
		love.graphics.setColor(255, 255, 255, 255)
		
	elseif opentimer ~= closeduration then --OPENING ANIMATION
		local alpha = opentimer/closeduration * 255
		local scale = opentimer/closeduration * 0.08 + 0.92
		
		love.graphics.setColor(255, 255, 255, alpha)
		love.graphics.draw(gamewindow, 400, 300, 0, scale, scale, 341, 282)
		love.graphics.draw(close, 400, 300, 0, scale, scale, -260, 282)
		love.graphics.setColor(255, 255, 255, 255)
	end
end

function nextgame()
	currentgame = currentgame + 1
	require ("game" .. currentgame)
	
	done = false
	
	codestring = love.filesystem.read( "game" .. currentgame .. ".lua" )
	
	--get codelength
	codelength = string.len(codestring)
	
	s1 = codestring:split("\n")
	
	for i = 1, #s1 do
		s2 = s1[i]:split("\t")
		for j = 1, #s2-1 do
			codelength = codelength - 1
		end
	end
	
	typedsymbols = 0
end

function startgame()
	running = true
	load()
end

function onclosebutton()
	local x, y = love.mouse.getPosition()
	
	if x >= 673 and x < 721 and y >= 31 and y < 50 then
		return true
	else
		return false
	end
end

function love.keypressed(key, unicode)
	if running == false then
		if key ~= "lshift" and key ~= "rshift" and key ~= "lctrl" and key ~= "rctrl" then
			if typedsymbols < codelength and done == false then
				typedsymbols = typedsymbols + charmultiplier
			end
		end
		
		if key == "f5" then
			if done then
				opentimer = 0
			end
		end
	end
end

function love.mousepressed(x, y, button)
	if onclosebutton() and running then
		running = false
		closetimer = 0
	end
end

function string:split(delimiter)
	local result = {}
	local from  = 1
	local delim_from, delim_to = string.find( self, delimiter, from  )
	while delim_from do
		table.insert( result, string.sub( self, from , delim_from-1 ) )
		from  = delim_to + 1
		delim_from, delim_to = string.find( self, delimiter, from  )
	end
	table.insert( result, string.sub( self, from  ) )
	return result
end